@@ -4,7 +4,19 @@
 import os
 import sys
 
-__all__ = ['adium', 'chatsecure', 'irssi', 'jitsi', 'pidgin', 'gajim', 'gnupg', 'xchat',]
+from pkg_resources import get_distribution, DistributionNotFound
+try:
+    _dist = get_distribution('keysync')
+    if not __file__.startswith(os.path.join(_dist.location, 'otrapps')):
+        raise DistributionNotFound
+except DistributionNotFound:
+    # probably running from source repo or another version is installed
+    __version__ = '(local version)'
+else:
+    __version__ = _dist.version
+
+
+__all__ = ['adium', 'chatsecure', 'irssi', 'jitsi', 'pidgin', 'gajim', 'gnupg', 'xchat', 'kopete',]
 
 if __name__ == '__main__':
     sys.path.insert(0, "../") # so the main() test suite can find otrapps module
@@ -16,6 +28,7 @@ import otrapps.pidgin
 import otrapps.gajim
 import otrapps.gnupg
 import otrapps.xchat
+import otrapps.kopete
 
 apps = { 'adium'     : otrapps.adium.AdiumProperties,
          'chatsecure': otrapps.chatsecure.ChatSecureProperties,
@@ -25,6 +38,7 @@ apps = { 'adium'     : otrapps.adium.AdiumProperties,
          'gajim'     : otrapps.gajim.GajimProperties,
          'gnupg'     : otrapps.gnupg.GnuPGProperties,
          'xchat'     : otrapps.xchat.XchatProperties,
+         'kopete'    : otrapps.kopete.KopeteProperties,
         }
 apps_supported = apps.keys()
 
